#!/bin/bash

tomte=""
logfile=/var/log/plasma-6.4-upgrade.log

if grep -q ubuntu-plasma /etc/apt/sources.list.d/*; then
    echo "Neon not found, exit" | tee -a "$logfile"
    exit 0
fi

if dpkg -l | grep -q tomte; then
    tomte="tuxedo-tomte"
fi

systemctl mask packagekit
killall -9 DiscoverNotifier

llang=$(echo "$LANG" | awk -F\_ '{print $1}')

if [ "$EUID" -ne 0 ]; then
    if [ "$llang" = "de" ]; then
	echo "Das Script muss als Root ausgeführt werden" | tee -a "$logfile"
    else
	echo "You need to run this script as root!" | tee -a "$logfile"
    fi
    exit 1
fi

if [ "$llang" = "de" ]; then
    echo "Sorge dafür, dass das installierte System auf dem aktuellen Stand ist (apt upgrade)." | tee -a "$logfile"
else
    echo "Make sure installed system is up to date (apt upgrade)." | tee -a "$logfile"
fi

DEBIAN_FRONTEND=noninteractive apt-get update | tee -a "$logfile"
if ! DEBIAN_FRONTEND=noninteractive apt-get --assume-yes upgrade | tee -a "$logfile";then
    if [ "$llang" = "de" ]; then
	echo "Systemaktualisierung nicht möglich. Bitte korrigieren Sie dieses Problem bevor Sie die Plasma Aktualisierung durchführen können." | tee -a "$logfile"
    else
	echo "System update not possible. Please correct this problem before you can perform the plasma update." | tee -a "$logfile"
    fi
    exit 1
fi

if dpkg -l | grep -q kdepim-addons; then
    pimaddons="1"
else
    pimaddons="0"
fi

rm -rf /etc/apt/apt.conf.d/99*
rm -rf /etc/apt/apt.conf.d/98*

echo "apt-get -y ~c" | tee -a "$logfile"

DEBIAN_FRONTEND=noninteractive apt-get update | tee -a "$logfile"
DEBIAN_FRONTEND=noninteractive apt-get -y purge ~c | tee -a "$logfile"
DEBIAN_FRONTEND=noninteractive apt-get -y autopurge | tee -a "$logfile"

if [ "$llang" = "de" ]; then
    echo "Kopiere neue Apt Sourcen und Preferences" | tee -a "$logfile"
else
    echo "Copy new apt sources and preferences" | tee -a "$logfile"
fi
read -p "Enter"
cp -af /usr/share/tuxedo/*.sources /etc/apt/sources.list.d/ | tee -a "$logfile"
cp -af /usr/share/tuxedo/30-* /etc/apt/preferences.d/ | tee -a "$logfile"
cp -af /usr/share/tuxedo/10-* /etc/apt/preferences.d/ | tee -a "$logfile"
cp -af /usr/share/tuxedo/9*-* /etc/apt/apt.conf.d/ | tee -a "$logfile"
echo ""

if [ "$llang" = "de" ]; then
    echo "Aktualisiere Paketquellen" | tee -a "$logfile"
else
    echo "Update package sources" | tee -a "$logfile"
fi

apt-get update | tee -a "$logfile"

echo "Full-Upgrade" | tee -a "$logfile"
read -p "Enter"
DEBIAN_FRONTEND=noninteractive apt-get --allow-downgrades --download-only --assume-yes  dist-upgrade | tee -a "$logfile"
DEBIAN_FRONTEND=noninteractive apt-get --allow-downgrades --assume-yes -o dpkg::options::="--force-confold" -o dpkg::options::="--force-confold" dist-upgrade --auto-remove | tee -a "$logfile" | tee -a "$logfile"
DEBIAN_FRONTEND=noninteractive apt-get -y purge $(dpkg -l | grep  -E "\+neon|vrelease|release\+" | awk '{print $2}') | tee -a "$logfile"
DEBIAN_FRONTEND=noninteractive apt-get -y autopurge | tee -a "$logfile"

if [ "$llang" = "de" ]; then
    echo "Repariere die entfernten libs" | tee -a "$logfile"
else
    echo "Fix for missing Libs" | tee -a "$logfile"
fi
read -p "Enter"
DEBIAN_FRONTEND=noninteractive apt-get --assume-yes -o dpkg::options::="--force-confold" -o dpkg::options::="--force-confold" --reinstall install $(dpkg -l | awk '/~tux1/{print $2}') plasma-desktop tuxedoos-desktop language-selector-common | tee -a "$logfile"

if [ "$llang" = "de" ]; then
    echo "Erzeuge Liste automatisch installierter Pakete" | tee -a "$logfile"
else
    echo "Create list of automaticly installed packages" | tee -a "$logfile"
fi
read -p "Enter"
apt-mark showauto > /tmp/auto.txt
DEBIAN_FRONTEND=noninteractive apt-get -y purge ~c | tee -a "$logfile"
apt-mark auto $(</tmp/auto.txt)

if [ "$pimaddons" = "1" ]; then
    DEBIAN_FRONTEND=noninteractive apt-get --assume-yes --allow-downgrades install kdepim-addons | tee -a "$logfile"
fi

if [ "$llang" = "de" ]; then
    echo "Lösche /home/*/.cache" | tee -a "$logfile"
else
    echo "Remove /home/*/.cache" | tee -a "$logfile"
fi
read -p "Enter"
rm -rf /home/*/.cache | tee -a "$logfile"
systemctl unmask packagekit | tee -a "$logfile"
DEBIAN_FRONTEND=noninteractive apt-get -y purge upgrader | tee -a "$logfile"
DEBIAN_FRONTEND=noninteractive apt-get -y install tuxedo-control-center | tee -a "$logfile"
DEBIAN_FRONTEND=noninteractive apt-get -y install --no-install-recommends tuxedo-base-files tuxedo-common-settings "$tomte" | tee -a "$logfile"
rm -f /etc/apt/preferences.d/30-*

echo "Reboot" | tee -a "$logfile"
read -p "Enter"
reboot
